@@ -9,7 +9,7 @@ package Lemonldap::NG::Manager::_i18n;
 
 use strict;
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '1.1.0';
+our $VERSION = '1.2.0';
 
 ## @method string translate(string text,string lang)
 # Returns $text translated in $lang.
@@ -48,72 +48,74 @@ __END__
 
 sub en {
     return {
-        _auth               => 'Authentication',
-        _authChoice         => 'Authentication choice',
-        _userDB             => 'User',
-        _passwordDB         => 'Password',
-        _issuerDB           => 'Issuer',
-        _timezone           => 'Time zone',
-        _session_id         => 'Session identifier',
-        _url                => 'Origin URL',
-        _user               => 'Login',
-        _password           => 'Password',
-        _utime              => 'Session timestamp',
-        _lastAuthnUTime     => 'Authentication timestamp',
-        _idp                => 'IDP EntityID',
-        _idpConfKey         => 'IDP configuration key',
-        _samlToken          => 'SAML token',
-        _lassoSessionDump   => 'Lasso session dump',
-        _lassoIdentityDump  => 'Lasso identity dump',
-        advancedParams      => 'Advanced parameters',
-        apacheParams        => 'Apache parameters',
-        apacheAuthnLevel    => 'Authentication level',
-        applicationList     => 'Categories and applications',
-        attributesAndMacros => 'Attributes and macros',
-        authChoiceModules   => 'Allowed modules',
-        authChoiceParam     => 'URL parameter',
-        authentication      => 'Authentication module',
-        authenticationLevel => 'Authentication level',
-        authenticationTitle => 'Authentication',
-        AuthLDAPFilter      => 'Authentication filter',
-        authParams          => 'Authentication modules',
-        dbiAuthChain        => 'Chain',
-        dbiAuthLoginCol     => 'Login field name',
-        dbiAuthnLevel       => 'Authentication level',
-        dbiAuthPassword     => 'Password',
-        dbiAuthPasswordCol  => 'Password field name',
-        dbiAuthPasswordHash => 'Hash scheme',
-        dbiAuthTable        => 'Authentication table',
-        dbiAuthUser         => 'User',
-        dbiConnection       => 'Connection',
-        dbiConnectionAuth   => 'Authentication process',
-        dbiConnectionUser   => 'User process',
-        dbiParams           => 'DBI parameters',
-        dbiPassword         => 'Password',
-        dbiPasswordMailCol  => 'Mail field name',
-        dbiSchema           => 'Schema',
-        dbiUserChain        => 'Chain',
-        dbiUserPassword     => 'Password',
-        dbiUserTable        => 'User table',
-        dbiUserUser         => 'User',
-        deleteNotification  => 'Mark notification as done',
-        deleteSession       => 'Delete session',
-        done                => 'done',
-        CAS_authnLevel      => 'Authentication level',
-        CAS_CAFile          => 'CA file',
-        CAS_gateway         => 'Gateway authentication',
-        CAS_pgtFile         => 'PGT file',
-        CAS_proxiedServices => 'Proxied services',
-        CAS_renew           => 'Renew authentication',
-        CAS_url             => 'Server URL',
-        casAttr             => 'CAS login',
-        casParams           => 'CAS parameters',
-        casStorage          => 'CAS sessions module name',
-        casStorageOptions   => 'CAS sessions module options',
-        cda                 => 'Multiple domains',
-        clickHereToForce    => 'Click here to force',
-        choiceParams        => 'Choice parameters',
-        Configuration       => 'Configuration',
+        _auth                  => 'Authentication',
+        _authChoice            => 'Authentication choice',
+        _userDB                => 'User',
+        _passwordDB            => 'Password',
+        _issuerDB              => 'Issuer',
+        _timezone              => 'Time zone',
+        _session_id            => 'Session identifier',
+        _url                   => 'Origin URL',
+        _user                  => 'Login',
+        _password              => 'Password',
+        _utime                 => 'Session timestamp',
+        _lastAuthnUTime        => 'Authentication timestamp',
+        _idp                   => 'IDP EntityID',
+        _idpConfKey            => 'IDP configuration key',
+        _samlToken             => 'SAML token',
+        _lassoSessionDump      => 'Lasso session dump',
+        _lassoIdentityDump     => 'Lasso identity dump',
+        advancedParams         => 'Advanced parameters',
+        apacheParams           => 'Apache parameters',
+        apacheAuthnLevel       => 'Authentication level',
+        applicationList        => 'Categories and applications',
+        attributesAndMacros    => 'Attributes and macros',
+        authChoiceModules      => 'Allowed modules',
+        authChoiceParam        => 'URL parameter',
+        authentication         => 'Authentication module',
+        authenticationLevel    => 'Authentication level',
+        authenticationTitle    => 'Authentication',
+        AuthLDAPFilter         => 'Authentication filter',
+        authParams             => 'Authentication modules',
+        dbiAuthChain           => 'Chain',
+        dbiAuthLoginCol        => 'Login field name',
+        dbiAuthnLevel          => 'Authentication level',
+        dbiAuthPassword        => 'Password',
+        dbiAuthPasswordCol     => 'Password field name',
+        dbiAuthPasswordHash    => 'Hash scheme',
+        dbiAuthTable           => 'Authentication table',
+        dbiAuthUser            => 'User',
+        dbiConnection          => 'Connection',
+        dbiConnectionAuth      => 'Authentication process',
+        dbiConnectionUser      => 'User process',
+        dbiParams              => 'DBI parameters',
+        dbiPassword            => 'Password',
+        dbiPasswordMailCol     => 'Mail field name',
+        dbiSchema              => 'Schema',
+        dbiUserChain           => 'Chain',
+        dbiUserPassword        => 'Password',
+        dbiUserTable           => 'User table',
+        dbiUserUser            => 'User',
+        deleteNotification     => 'Mark notification as done',
+        deleteSession          => 'Delete session',
+        done                   => 'done',
+        CAS_authnLevel         => 'Authentication level',
+        CAS_CAFile             => 'CA file',
+        CAS_gateway            => 'Gateway authentication',
+        CAS_pgtFile            => 'PGT file',
+        CAS_proxiedServices    => 'Proxied services',
+        CAS_renew              => 'Renew authentication',
+        CAS_url                => 'Server URL',
+        casAccessControlPolicy => 'Access control policy',
+        casAttr                => 'CAS login',
+        casParams              => 'CAS parameters',
+        casStorage             => 'CAS sessions module name',
+        casStorageOptions      => 'CAS sessions module options',
+        cda                    => 'Multiple domains',
+        checkXSS               => 'Check XSS attacks',
+        clickHereToForce       => 'Click here to force',
+        choiceParams           => 'Choice parameters',
+        Configuration          => 'Configuration',
         confModuledeprecated =>
 'This module has been deprecated, set "forceUpload=1" in lemonldap-ng.ini to use it',
         confSaved                       => 'Configuration saved',
@@ -130,13 +132,15 @@ sub en {
         error                           => 'Error',
         exportedAttr                    => 'SOAP exported attributes',
         exportedVars                    => 'Exported Variables',
+        failedLoginNumber               => 'Number of registered failed logins',
         generalParameters               => 'General Parameters',
         globalStorage                   => 'Apache::Session module',
         globalStorageOptions            => 'Apache::Session module parameters',
-        grantSessionRule                => 'Opening conditions',
+        grantSessionRules               => 'Opening conditions',
         groups                          => 'Groups',
         headers                         => 'HTTP Headers',
         hideOldPassword                 => 'Hide old password',
+        httpOnly                        => 'Javascript protection',
         https                           => 'HTTPS',
         internalReference               => 'Internal reference',
         ipAddr                          => 'IP address',
@@ -155,6 +159,7 @@ sub en {
         issuerDBOpenIDPath              => 'Path',
         issuerDBOpenIDRule              => 'Use rule',
         issuerDBOpenIDOptions           => 'Options',
+        jsRedirect                      => 'Redirection message',
         key                             => 'Encryption key',
         ldap                            => 'LDAP',
         ldapAuthnLevel                  => 'Authentication level',
@@ -184,6 +189,8 @@ sub en {
         ldapTimeout                     => 'Timeout',
         ldapUsePasswordResetAttribute   => 'Use reset attribute',
         ldapVersion                     => 'Version',
+        loginHistory                    => 'Login history',
+        loginHistoryEnabled             => 'Activation',
         logoutServices                  => 'Logout forward',
         logParams                       => 'Logs',
         macros                          => 'Macros',
@@ -195,12 +202,14 @@ sub en {
         mailFrom                        => 'Mail sender',
         mailHeaders                     => 'Mail headers',
         mailLDAPFilter                  => 'Mail filter',
-        mailOther                       => 'Other',
-        mailReplyTo                     => 'Reply address',
+        mailOnPasswordChange   => 'Send a mail when password is changed',
+        mailOther              => 'Other',
+        mailReplyTo            => 'Reply address',
         mailSessionKey         => 'Session key containing mail address',
         mailSubject            => 'Success mail subject',
         mailTimeout            => 'Validity time of a password reset request',
         mailUrl                => 'Page URL',
+        maintenance            => 'Maintenance mode',
         managerDn              => 'Account',
         managerPassword        => 'Password',
         memberOfSSOGroups      => 'Member of SSO groups',
@@ -251,9 +260,11 @@ sub en {
         portal                      => 'URL',
         portalAntiFrame             => 'Anti frame protection',
         portalAutocomplete          => 'Auto complete',
+        portalCheckLogins           => 'Check last logins',
         portalCustomization         => 'Customization',
         portalDisplayAppslist       => 'Applications list',
         portalDisplayChangePassword => 'Password change',
+        portalDisplayLoginHistory   => 'Login History',
         portalDisplayLogout         => 'Logout',
         portalDisplayResetPassword  => 'Reset password',
         portalForceAuthn            => 'Force authentication',
@@ -261,14 +272,20 @@ sub en {
         portalModules               => 'Modules activation',
         portalOpenLinkInNewWindow   => 'New window',
         portalParams                => 'Portal',
+        portalRedirection           => 'Portal redirections',
         portalRequireOldPassword    => 'Require old password',
         portalSkin                  => 'Skin',
         portalUserAttr              => 'User attribute',
         post                        => 'Form replay',
         proxyParams                 => 'Proxy parameters',
         purgeNotification           => 'Delete notification definitely',
+        radiusAuthnLevel            => 'Authentication level',
+        radiusParams                => 'Radius parameters',
+        radiusSecret                => 'Shared secret',
+        radiusServer                => 'Server hostname',
         randomPasswordRegexp        => 'Regexp for password generation',
         redirection                 => 'Handler redirections',
+        reloadUrls                  => 'Configuration reload',
         remoteCookieName            => 'Cookie name',
         remoteGlobalStorage         => 'Sessions module',
         remoteGlobalStorageOptions  => 'Sessions module options',
@@ -276,6 +293,7 @@ sub en {
         remotePortal                => 'Portal URL',
         rules                       => 'Rules',
         securedCookie               => 'Secured Cookie (SSL)',
+        secureTokenAllowOnError     => 'Allow requests in error',
         secureTokenAttribute        => 'Attribute to store',
         secureTokenExpiration       => 'Token expiration',
         secureTokenHandler          => 'Secure Token',
@@ -285,6 +303,7 @@ sub en {
         security                    => 'Security',
         session                     => 'session',
         sessions                    => 'sessions',
+        sessionDataToRemember       => 'Session data to store',
         sessionDeleted              => 'The session was deleted',
         sessionParams               => 'Sessions',
         sessionStartedAt            => 'Session started on',
@@ -294,6 +313,7 @@ sub en {
         singleSession               => 'One session only by user',
         singleUserByIP              => 'One user by IP address',
         slaveAuthnLevel             => 'Authentication level',
+        slaveMasterIP               => 'Master\'s IP address',
         slaveParams                 => 'Slave parameters',
         slaveUserHeader             => "Header for user login",
         SMTPAuthPass                => 'SMTP password',
@@ -305,12 +325,11 @@ sub en {
         soapSessionService          => 'SOAP sessions end point',
         specialHandlers             => 'Special Handlers',
         SSLAuthnLevel               => 'Authentication level',
-        SSLLDAPField                => 'LDAP attribute used in filter',
         sslParams                   => 'SSL parameters',
-        SSLRequire                  => 'SSL Required',
         SSLVar                      => 'Extracted certificate field',
         startTime                   => 'Creation date',
         storePassword               => 'Store user password in session datas',
+        successLoginNumber          => 'Number of registered logins',
         sympaHandler                => 'Sympa',
         sympaMailKey                => 'Mail session key',
         sympaSecret                 => 'Shared secret',
@@ -338,6 +357,7 @@ sub en {
         useXForwardedForIP          => "Use X-Forwarded-For",
         variables                   => "Variables",
         vhostHttps                  => 'HTTPS',
+        vhostMaintenance            => 'Maintenance mode',
         vhostOptions                => 'Options',
         vhostPort                   => 'Port',
         virtualHosts                => 'Virtual Hosts',
@@ -478,72 +498,74 @@ sub en {
 sub fr {
     use utf8;
     return {
-        _auth               => 'Authentification',
-        _authChoice         => 'Choix d\'authentification',
-        _userDB             => 'Utilisateur',
-        _passwordDB         => 'Mot de passe',
-        _issuerDB           => 'Fournisseur',
-        _timezone           => 'Zone horaire',
-        _session_id         => 'Identifiant de session',
-        _url                => "URL d'origine",
-        _user               => 'Identifiant',
-        _password           => 'Mot de passe',
-        _utime              => 'Tampon de la session',
-        _lastAuthnUTime     => 'Tampon d\'authentification ',
-        _idp                => 'Identifiant d\'entité de l\'IDP',
-        _idpConfKey         => 'Clé de configuration de l\'IDP',
-        _samlToken          => ' Jeton SAML ',
-        _lassoSessionDump   => ' Dump session Lasso ',
-        _lassoIdentityDump  => 'Dump identité Lasso',
-        advancedParams      => 'Paramètres avancés',
-        apacheParams        => 'Paramètres Apache',
-        apacheAuthnLevel    => 'Niveau d\'authentification',
-        applicationList     => 'Catégories et applications',
-        attributesAndMacros => 'Attributs et macros',
-        authChoiceModules   => 'Modules autorisés',
-        authChoiceParam     => 'Parmètre de l\'URL',
-        authentication      => "Module d'authentification",
-        authenticationLevel => 'Niveau d\'authentification',
-        authenticationTitle => 'Authentification',
-        AuthLDAPFilter      => 'Filtre d\'authentification',
-        authParams          => "Modules d'authentification",
-        dbiAuthChain        => 'Chaîne',
-        dbiAuthLoginCol     => 'Champ identifiant',
-        dbiAuthnLevel       => 'Niveau d\'authentification',
-        dbiAuthPassword     => 'Mot de passe',
-        dbiAuthPasswordCol  => 'Champ mot de passe',
-        dbiAuthPasswordHash => 'Schéma de hachage',
-        dbiAuthTable        => 'Table authentification',
-        dbiAuthUser         => 'Utilisateur',
-        dbiConnection       => 'Connexion',
-        dbiConnectionAuth   => 'Authentification',
-        dbiConnectionUser   => 'Utilisateurs',
-        dbiParams           => 'Paramètres DBI',
-        dbiPassword         => 'Mot de passe',
-        dbiPasswordMailCol  => 'Champ mail',
-        dbiSchema           => 'Schéma',
-        dbiUserChain        => 'Chaîne',
-        dbiUserPassword     => 'Mot de passe',
-        dbiUserTable        => 'Table des utilisateurs',
-        dbiUserUser         => 'Utilisateur',
-        deleteNotification  => 'Marquer la notification comme validée',
-        deleteSession       => 'Effacer la session',
-        done                => 'validée',
-        CAS_authnLevel      => 'Niveau d\'authentification',
-        CAS_CAFile          => 'Fichier d\'AC',
-        CAS_gateway         => 'Authentification transparente',
-        CAS_pgtFile         => 'Fichier de PGT',
-        CAS_renew           => 'Renouveller l\'authentication',
-        CAS_proxiedServices => 'Services mandatés',
-        CAS_url             => 'URL du serveur',
-        casAttr             => 'Identifiant CAS',
-        casParams           => 'Paramètres CAS',
-        casStorage          => 'Nom du module des session CAS',
-        casStorageOptions   => 'Options du module des sessions CAS',
-        cda                 => 'Domaines multiples',
-        clickHereToForce    => 'Cliquer ici pour forcer',
-        choiceParams        => 'Paramètres des choix',
-        Configuration       => 'Configuration',
+        _auth                  => 'Authentification',
+        _authChoice            => 'Choix d\'authentification',
+        _userDB                => 'Utilisateur',
+        _passwordDB            => 'Mot de passe',
+        _issuerDB              => 'Fournisseur',
+        _timezone              => 'Zone horaire',
+        _session_id            => 'Identifiant de session',
+        _url                   => "URL d'origine",
+        _user                  => 'Identifiant',
+        _password              => 'Mot de passe',
+        _utime                 => 'Tampon de la session',
+        _lastAuthnUTime        => 'Tampon d\'authentification ',
+        _idp                   => 'Identifiant d\'entité de l\'IDP',
+        _idpConfKey            => 'Clé de configuration de l\'IDP',
+        _samlToken             => ' Jeton SAML ',
+        _lassoSessionDump      => ' Dump session Lasso ',
+        _lassoIdentityDump     => 'Dump identité Lasso',
+        advancedParams         => 'Paramètres avancés',
+        apacheParams           => 'Paramètres Apache',
+        apacheAuthnLevel       => 'Niveau d\'authentification',
+        applicationList        => 'Catégories et applications',
+        attributesAndMacros    => 'Attributs et macros',
+        authChoiceModules      => 'Modules autorisés',
+        authChoiceParam        => 'Parmètre de l\'URL',
+        authentication         => "Module d'authentification",
+        authenticationLevel    => 'Niveau d\'authentification',
+        authenticationTitle    => 'Authentification',
+        AuthLDAPFilter         => 'Filtre d\'authentification',
+        authParams             => "Modules d'authentification",
+        dbiAuthChain           => 'Chaîne',
+        dbiAuthLoginCol        => 'Champ identifiant',
+        dbiAuthnLevel          => 'Niveau d\'authentification',
+        dbiAuthPassword        => 'Mot de passe',
+        dbiAuthPasswordCol     => 'Champ mot de passe',
+        dbiAuthPasswordHash    => 'Schéma de hachage',
+        dbiAuthTable           => 'Table authentification',
+        dbiAuthUser            => 'Utilisateur',
+        dbiConnection          => 'Connexion',
+        dbiConnectionAuth      => 'Authentification',
+        dbiConnectionUser      => 'Utilisateurs',
+        dbiParams              => 'Paramètres DBI',
+        dbiPassword            => 'Mot de passe',
+        dbiPasswordMailCol     => 'Champ mail',
+        dbiSchema              => 'Schéma',
+        dbiUserChain           => 'Chaîne',
+        dbiUserPassword        => 'Mot de passe',
+        dbiUserTable           => 'Table des utilisateurs',
+        dbiUserUser            => 'Utilisateur',
+        deleteNotification     => 'Marquer la notification comme validée',
+        deleteSession          => 'Effacer la session',
+        done                   => 'validée',
+        CAS_authnLevel         => 'Niveau d\'authentification',
+        CAS_CAFile             => 'Fichier d\'AC',
+        CAS_gateway            => 'Authentification transparente',
+        CAS_pgtFile            => 'Fichier de PGT',
+        CAS_renew              => 'Renouveller l\'authentication',
+        CAS_proxiedServices    => 'Services mandatés',
+        CAS_url                => 'URL du serveur',
+        casAccessControlPolicy => "Politique de contrôle d'accès",
+        casAttr                => 'Identifiant CAS',
+        casParams              => 'Paramètres CAS',
+        casStorage             => 'Nom du module des session CAS',
+        casStorageOptions      => 'Options du module des sessions CAS',
+        cda                    => 'Domaines multiples',
+        checkXSS               => 'Contrôler les attaques XSS',
+        clickHereToForce       => 'Cliquer ici pour forcer',
+        choiceParams           => 'Paramètres des choix',
+        Configuration          => 'Configuration',
         confModuledeprecated =>
 "Ce module est obsolète, indiquez \"forceUpload=1\" dans le fichier lemonldap-ng.ini pour l'utiliser",
         confSaved        => 'Configuration sauvegardée',
@@ -560,50 +582,53 @@ sub fr {
         error          => 'Erreur',
         exportedAttr   => 'Attributs exportés par le portail (SOAP)',
         exportedVars   => 'Attributs à exporter',
-        generalParameters            => 'Paramètres généraux',
-        globalStorage                => 'Module Apache::Session',
-        globalStorageOptions         => 'Paramètres du module Apache::Session',
-        grantSessionRule             => "Conditions d'ouverture",
-        groups                       => 'Groupes',
-        headers                      => 'En-têtes HTTP',
-        hideOldPassword              => "Masquer l'ancien mot de passe",
-        https                        => 'HTTPS',
-        internalReference            => 'Référence interne ',
-        ipAddr                       => 'Adresse IP',
-        issuerParams                 => 'Modules fournisseur',
-        issuerDBSAML                 => 'SAML',
-        issuerDBSAMLActivation       => 'Activation',
-        issuerDBSAMLPath             => 'Chemin',
-        issuerDBSAMLRule             => 'Règle d\'utilisation',
-        issuerDBCAS                  => 'CAS',
-        issuerDBCASActivation        => 'Activation',
-        issuerDBCASPath              => 'Chemin',
-        issuerDBCASRule              => 'Règle d\'utilisation',
-        issuerDBCASOptions           => 'Options',
-        issuerDBOpenID               => 'OpenID',
-        issuerDBOpenIDActivation     => 'Activation',
-        issuerDBOpenIDPath           => 'Chemin',
-        issuerDBOpenIDRule           => 'Règle d\'utilisation',
-        issuerDBOpenIDOptions        => 'Options',
-        key                          => 'Clef de chiffrement',
-        ldap                         => 'LDAP',
-        ldapAuthnLevel               => 'Niveau d\'authentification',
-        ldapBase                     => 'Base de recherche des utilisateurs',
-        ldapChangePasswordAsUser     => 'Changement en tant qu\'utilisateur',
-        ldapConnection               => 'Connexion',
-        ldapFilters                  => 'Filtres',
-        LDAPFilter                   => 'Filtre par défaut',
-        ldapGroupAttributeName       => 'Attribut cible',
-        ldapGroupAttributeNameGroup  => 'Attribut source groupe',
-        ldapGroupAttributeNameSearch => 'Attributs recherchés',
-        ldapGroupAttributeNameUser   => 'Attribut source utilisateur',
-        ldapGroupBase                => 'Base de recherche',
-        ldapGroupObjectClass         => 'Classe d\'objet',
-        ldapGroupRecursive           => 'Recursif',
-        ldapGroups                   => 'Groupes',
-        ldapParams                   => 'Paramètres LDAP',
-        ldapPassword                 => 'Mot de passe',
-        ldapPasswordResetAttribute   => 'Attribut de réinitialisation',
+        failedLoginNumber      => 'Nombre d\'échecs de connexion mémorisés',
+        generalParameters      => 'Paramètres généraux',
+        globalStorage          => 'Module Apache::Session',
+        globalStorageOptions   => 'Paramètres du module Apache::Session',
+        grantSessionRules      => "Conditions d'ouverture",
+        groups                 => 'Groupes',
+        headers                => 'En-têtes HTTP',
+        hideOldPassword        => "Masquer l'ancien mot de passe",
+        httpOnly               => 'Protection contre javascript',
+        https                  => 'HTTPS',
+        internalReference      => 'Référence interne ',
+        ipAddr                 => 'Adresse IP',
+        issuerParams           => 'Modules fournisseur',
+        issuerDBSAML           => 'SAML',
+        issuerDBSAMLActivation => 'Activation',
+        issuerDBSAMLPath       => 'Chemin',
+        issuerDBSAMLRule       => 'Règle d\'utilisation',
+        issuerDBCAS            => 'CAS',
+        issuerDBCASActivation  => 'Activation',
+        issuerDBCASPath        => 'Chemin',
+        issuerDBCASRule        => 'Règle d\'utilisation',
+        issuerDBCASOptions     => 'Options',
+        issuerDBOpenID         => 'OpenID',
+        issuerDBOpenIDActivation        => 'Activation',
+        issuerDBOpenIDPath              => 'Chemin',
+        issuerDBOpenIDRule              => 'Règle d\'utilisation',
+        issuerDBOpenIDOptions           => 'Options',
+        jsRedirect                      => 'Message de redirection',
+        key                             => 'Clef de chiffrement',
+        ldap                            => 'LDAP',
+        ldapAuthnLevel                  => 'Niveau d\'authentification',
+        ldapBase                        => 'Base de recherche des utilisateurs',
+        ldapChangePasswordAsUser        => 'Changement en tant qu\'utilisateur',
+        ldapConnection                  => 'Connexion',
+        ldapFilters                     => 'Filtres',
+        LDAPFilter                      => 'Filtre par défaut',
+        ldapGroupAttributeName          => 'Attribut cible',
+        ldapGroupAttributeNameGroup     => 'Attribut source groupe',
+        ldapGroupAttributeNameSearch    => 'Attributs recherchés',
+        ldapGroupAttributeNameUser      => 'Attribut source utilisateur',
+        ldapGroupBase                   => 'Base de recherche',
+        ldapGroupObjectClass            => 'Classe d\'objet',
+        ldapGroupRecursive              => 'Récursif',
+        ldapGroups                      => 'Groupes',
+        ldapParams                      => 'Paramètres LDAP',
+        ldapPassword                    => 'Mot de passe',
+        ldapPasswordResetAttribute      => 'Attribut de réinitialisation',
         ldapPasswordResetAttributeValue => 'Valeur de réinitialisation',
         ldapPpolicyControl              => 'Contrôle password policy',
         ldapPort                        => 'Port',
@@ -614,24 +639,29 @@ sub fr {
         ldapTimeout     => 'Temps maximum d\'inactivité',
         ldapUsePasswordResetAttribute =>
           'Utiliser l\'attribut de réinitialisation',
-        ldapVersion        => 'Version',
-        logoutServices     => 'Transfert de la déconnexion',
-        logParams          => 'Journalisation',
-        macros             => 'Macros',
-        mailBody           => 'Contenu du message de succès',
-        mailCharset        => 'Charset',
-        mailConfirmBody    => 'Contenu du message de confirmation',
-        mailConfirmSubject => 'Sujet du message de confirmation',
-        mailContent        => 'Contenu du mail',
-        mailFrom           => 'Expéditeur du message',
-        mailHeaders        => 'En-têtes du mail',
-        mailLDAPFilter     => 'Filtre mail',
-        mailOther          => 'Autres',
-        mailReplyTo        => 'Adresse de réponse',
-        mailSessionKey     => 'Clé de session contenant l\'adresse email',
-        mailSubject        => 'Sujet du message de succès',
+        ldapVersion         => 'Version',
+        loginHistory        => 'Historique des connexions',
+        loginHistoryEnabled => 'Activation',
+        logoutServices      => 'Transfert de la déconnexion',
+        logParams           => 'Journalisation',
+        macros              => 'Macros',
+        mailBody            => 'Contenu du message de succès',
+        mailCharset         => 'Charset',
+        mailConfirmBody     => 'Contenu du message de confirmation',
+        mailConfirmSubject  => 'Sujet du message de confirmation',
+        mailContent         => 'Contenu du mail',
+        mailFrom            => 'Expéditeur du message',
+        mailHeaders         => 'En-têtes du mail',
+        mailLDAPFilter      => 'Filtre mail',
+        mailOnPasswordChange =>
+          "Envoi d'un mail quand le mot de passe est changé",
+        mailOther      => 'Autres',
+        mailReplyTo    => 'Adresse de réponse',
+        mailSessionKey => 'Clé de session contenant l\'adresse email',
+        mailSubject    => 'Sujet du message de succès',
         mailTimeout => "Durée de validité d'une demande de réinitialisation",
         mailUrl     => 'URL de la page',
+        maintenance => 'Mode maintenance',
         managerDn   => 'Compte de connexion LDAP',
         managerPassword     => 'Mot de passe LDAP',
         memberOfSSOGroups   => 'Membre des groupes SSO',
@@ -672,7 +702,7 @@ sub fr {
         openIdSreg_postcode         => 'Code postal',
         openIdSreg_timezone         => 'Zone horaire',
         openIdSreg_country          => 'Pays',
-        openIdSreg_gender           => 'Gendre',
+        openIdSreg_gender           => 'Genre',
         openIdSreg_email            => 'Email',
         openIdSreg_dob              => 'Date de naissance',
         openIdSPList                => 'Domaines autorisés',
@@ -685,9 +715,11 @@ sub fr {
         portal                      => 'URL',
         portalAntiFrame             => 'Protection anti frame',
         portalAutocomplete          => 'Auto complétion',
+        portalCheckLogins           => 'Vérifier l\'historique',
         portalCustomization         => 'Personnalisation',
         portalDisplayAppslist       => 'Liste des applications',
         portalDisplayChangePassword => 'Changement de mot de passe',
+        portalDisplayLoginHistory   => 'Historique des connexions',
         portalDisplayLogout         => 'Déconnexion',
         portalDisplayResetPassword  => 'Réinitialisation de mot de passe',
         portalForceAuthn            => 'Authentication forcée',
@@ -695,15 +727,21 @@ sub fr {
         portalModules               => 'Modules',
         portalOpenLinkInNewWindow   => 'Nouvelle fenêtre',
         portalParams                => 'Portail',
+        portalRedirection           => 'Redirections du portail',
         portalRequireOldPassword    => 'Ancien mot de passe requis',
         portalSkin                  => 'Thème visuel',
         portalUserAttr              => "Attribut de l'utilisateur",
         post                        => 'Rejeu de formulaires',
         proxyParams                 => 'Paramètres Proxy',
         purgeNotification => 'Supprimer définitivement la notification',
+        radiusAuthnLevel  => "Niveau d'authentification",
+        radiusParams      => 'Paramètres Radius',
+        radiusSecret      => 'Secret partagé',
+        radiusServer      => "Nom d'hôte du serveur",
         randomPasswordRegexp =>
           'Expression regulière pour la génération des mots de passe',
         redirection                 => 'Redirections du Handler',
+        reloadUrls                  => 'Mise à jour de la configuration',
         remoteCookieName            => 'Nom du cookie',
         remoteGlobalStorage         => 'Module des sessions',
         remoteGlobalStorageOptions  => 'Options du module des sessions',
@@ -711,6 +749,7 @@ sub fr {
         remotePortal                => 'URL du portail',
         rules                       => 'Règles',
         securedCookie               => 'Cookie sécurisé (SSL)',
+        secureTokenAllowOnError     => 'Autoriser les requêtes en erreur',
         secureTokenAttribute        => 'Attribut à stocker',
         secureTokenExpiration       => 'Expiration du jeton',
         secureTokenHandler          => 'Jeton sécurisé',
@@ -720,59 +759,61 @@ sub fr {
         security                    => 'Sécurité',
         session                     => 'session',
         sessions                    => 'sessions',
+        sessionDataToRemember       => 'Données de session à conserver',
         sessionDeleted              => 'La session a été supprimée',
         sessionParams               => 'Sessions',
         sessionStartedAt            => 'Session démarrée le ',
         sessionStorage              => 'Stockage des sessions',
         sessionTitle                => 'Contenu de la session',
-        singleIP                    => 'Une seule IP par utilisateur',
-        singleSession               => 'Une seule session par utilisateur',
-        singleUserByIP              => 'Une seule adresse IP par utilisateur',
-        slaveAuthnLevel             => 'Niveau d\'authentification',
-        slaveParams                 => 'Paramètres Slave',
-        slaveUserHeader             => "En-tête identifiant l'utilisateur",
-        SMTPAuthPass                => 'Mot de passe SMTP',
-        SMTPAuthUser                => 'Utilisateur SMTP',
-        SMTPServer                  => 'Serveur SMTP',
-        soap                        => 'SOAP',
-        Soap                        => 'Activation',
-        soapAuthService             => 'URL du portail',
-        soapSessionService          => 'Point d\'accès SOAP des sessions',
-        specialHandlers             => 'Handlers spéciaux',
-        SSLAuthnLevel               => 'Niveau d\'authentification',
-        SSLLDAPField                => 'Attribut LDAP pour le filtre',
-        sslParams                   => 'Paramètres SSL',
-        SSLRequire                  => 'SSL Requis',
-        SSLVar                      => 'Champ extrait du certificat',
-        startTime                   => 'Date de création',
-        storePassword   => "Stocke le mot de passe de l'utilisateur en session",
-        sympaHandler    => 'Sympa',
-        sympaMailKey    => 'Clé de session pour le mail',
-        sympaSecret     => 'Secret partagé',
-        syntaxError     => 'Erreur de syntaxe',
-        syslog          => 'Facilité syslog',
-        timeout         => 'Durée de vie maximale des sessions',
-        timeoutActivity => 'Délai d\'expiration des sessions',
-        trustedDomains  => 'Domaines appouvés',
-        twitterAppName  => 'Nom de l\'application',
-        twitterAuthnLevel => 'Niveau d\'authentification',
-        twitterKey        => 'Clé de l\'API',
-        twitterParams     => 'Paramètres Twitter',
-        twitterSecret     => 'Secret de l\'API',
-        unknownError      => 'Erreur inconnue',
-        updateTime        => 'Date de mise à jour',
-        uploadDenied      => 'Téléchargement refusé',
-        user              => 'utilisateur',
-        users             => 'utilisateurs',
-        userDB            => "Module d'utilisateurs",
-        userControl       => "Contrôle du nom d'utilisateur",
-        userPivot         => 'Champ identifiant dans la table des utilisateurs',
+        singleIP           => 'Une seule session par couple utilisateur/IP',
+        singleSession      => 'Une seule session par utilisateur',
+        singleUserByIP     => 'Un seul utilisateur par IP',
+        slaveAuthnLevel    => 'Niveau d\'authentification',
+        slaveMasterIP      => 'IP accréditées',
+        slaveParams        => 'Paramètres Slave',
+        slaveUserHeader    => "En-tête identifiant l'utilisateur",
+        SMTPAuthPass       => 'Mot de passe SMTP',
+        SMTPAuthUser       => 'Utilisateur SMTP',
+        SMTPServer         => 'Serveur SMTP',
+        soap               => 'SOAP',
+        Soap               => 'Activation',
+        soapAuthService    => 'URL du portail',
+        soapSessionService => 'Point d\'accès SOAP des sessions',
+        specialHandlers    => 'Handlers spéciaux',
+        SSLAuthnLevel      => 'Niveau d\'authentification',
+        sslParams          => 'Paramètres SSL',
+        SSLVar             => 'Champ extrait du certificat',
+        startTime          => 'Date de création',
+        storePassword => "Stocke le mot de passe de l'utilisateur en session",
+        successLoginNumber => 'Nombre de connexions mémorisées',
+        sympaHandler       => 'Sympa',
+        sympaMailKey       => 'Clé de session pour le mail',
+        sympaSecret        => 'Secret partagé',
+        syntaxError        => 'Erreur de syntaxe',
+        syslog             => 'Facilité syslog',
+        timeout            => 'Durée de vie maximale des sessions',
+        timeoutActivity    => 'Délai d\'expiration des sessions',
+        trustedDomains     => 'Domaines approuvés',
+        twitterAppName     => 'Nom de l\'application',
+        twitterAuthnLevel  => 'Niveau d\'authentification',
+        twitterKey         => 'Clé de l\'API',
+        twitterParams      => 'Paramètres Twitter',
+        twitterSecret      => 'Secret de l\'API',
+        unknownError       => 'Erreur inconnue',
+        updateTime         => 'Date de mise à jour',
+        uploadDenied       => 'Téléchargement refusé',
+        user               => 'utilisateur',
+        users              => 'utilisateurs',
+        userDB             => "Module d'utilisateurs",
+        userControl        => "Contrôle du nom d'utilisateur",
+        userPivot => 'Champ identifiant dans la table des utilisateurs',
         useRedirectOnError     => 'Redirection pour les erreurs',
         useRedirectOnForbidden => 'Redirection pour les accès interdits',
         useSafeJail            => 'Utiliser la cage Safe',
         useXForwardedForIP     => "Utiliser X-Forwarded-For",
         variables              => "Variables",
         vhostHttps             => 'HTTPS',
+        vhostMaintenance       => 'Mode maintenance',
         vhostOptions           => 'Options',
         vhostPort              => 'Port',
         virtualHosts           => 'Hôtes virtuels',
